@@ -14,16 +14,15 @@
 #' processCheckmarkField(file_path="file_path")
 #' }
 
-processCheckmarkField <- function(file_path=NULL,checkmarkType="empty",  region="-1,-1,-1,-1",correctionAllowed="false", pdfPassword="",description=""){
-	app_id=getOption("AbbyyAppId"); app_pass=getOption("AbbyyAppPassword")
-	if(is.null(app_id) | is.null(app_pass)) stop("Please set application id and password using setapp(c('app_id', 'app_pass')).")
-	
+processCheckmarkField <- function(file_path=NULL,checkmarkType="empty",  region="-1,-1,-1,-1",correctionAllowed="false", pdfPassword="",description="")
+{
+
 	if(is.null(file_path)) stop("Must specify file_path")
 
 	querylist = list(checkmarkType=checkmarkType, region=region,correctionAllowed=correctionAllowed,pdfPassword=pdfPassword,description=description)
-	res <- POST("http://cloud.ocrsdk.com/processCheckmarkField", authenticate(app_id, app_pass), query=querylist, body=upload_file(file_path))
-	stop_for_status(res)
-	processdetails <- xmlToList(httr::content(res))
+	
+	body=upload_file(file_path)
+	processdetails <- abbyy_POST("processCheckmarkField", query=querylist, body=body)
 	
 	resdf <- do.call(rbind.data.frame, processdetails) # collapse to a data.frame
 	names(resdf) <- names(processdetails[[1]])[1:length(resdf)] # names for the df, adjust for <7
