@@ -22,15 +22,12 @@
 
 processDocument <- function(taskId = NULL, language="English", profile="documentConversion",textType="normal", imageSource="auto", correctOrientation="true", 
 						correctSkew="true",readBarcodes="false",exportFormat="txt", description=NULL, pdfPassword=NULL){
-	app_id=getOption("AbbyyAppId"); app_pass=getOption("AbbyyAppPassword")
-	if(is.null(app_id) | is.null(app_pass)) stop("Please set application id and password using setapp(c('app_id', 'app_pass')).")
 	
 	querylist = list(taskId = taskId, language=language, profile=profile,textType=textType, imageSource=imageSource, correctOrientation=correctOrientation, 
 						correctSkew=correctSkew,readBarcodes=readBarcodes,exportFormat=exportFormat, description=description, pdfPassword=pdfPassword)
-	res <- GET("http://cloud.ocrsdk.com/processDocument", authenticate(app_id, app_pass), query=querylist)
-	stop_for_status(res)
-	processdetails <- xmlToList(httr::content(res))
-	
+
+	processdetails <- abbyy_GET("processDocument", query=querylist)
+		
 	resdf <- do.call(rbind.data.frame, processdetails) # collapse to a data.frame
 	names(resdf) <- names(processdetails[[1]])
 	row.names(resdf) <- 1:nrow(resdf)	# row.names for the df
